@@ -11,20 +11,26 @@
  *
  * @package PhpMyAdmin
  */
-use PMA\libraries\Response;
-use PMA\libraries\plugins\export\ExportSql;
+use PhpMyAdmin\DatabaseInterface;
+use PhpMyAdmin\Display\CreateTable;
+use PhpMyAdmin\Message;
+use PhpMyAdmin\Operations;
+use PhpMyAdmin\Plugins;
+use PhpMyAdmin\Plugins\Export\ExportSql;
+use PhpMyAdmin\Relation;
+use PhpMyAdmin\RelationCleanup;
+use PhpMyAdmin\Response;
+use PhpMyAdmin\Util;
 
 /**
  * requirements
  */
 require_once 'libraries/common.inc.php';
-require_once 'libraries/display_create_table.lib.php';
 
 /**
  * functions implementation for this script
  */
-require_once 'libraries/check_user_privileges.lib.php';
-require_once 'libraries/operations.lib.php';
+require_once 'libraries/check_user_privileges.inc.php';
 
 // add a javascript file for jQuery functions to handle Ajax actions
 $response = Response::getInstance();
@@ -34,6 +40,8 @@ $scripts->addFile('db_operations.js');
 
 $sql_query = '';
 
+$operations = new Operations();
+
 /**
  * Rename/move or copy database
  */
@@ -47,7 +55,7 @@ if (strlen($GLOBALS['db']) > 0
     }
 
     if (! isset($_REQUEST['newname']) || strlen($_REQUEST['newname']) === 0) {
-        $message = PMA\libraries\Message::error(__('The database name is empty!'));
+        $message = Message::error(__('The database name is empty!'));
     } else {
         // lower_case_table_names=1 `DB` becomes `db`
         if ($GLOBALS['dbi']->getLowerCaseNames() === '1') {
@@ -57,13 +65,13 @@ if (strlen($GLOBALS['db']) > 0
         }
 
         if ($_REQUEST['newname'] === $_REQUEST['db']) {
-            $message = PMA\libraries\Message::error(
+            $message = Message::error(
                 __('Cannot copy database to the same name. Change the name and try again.')
             );
         } else {
             $_error = false;
             if ($move || ! empty($_REQUEST['create_database_before_copying'])) {
-                PMA_createDbBeforeCopy();
+                $operations->createDbBeforeCopy();
             }
 
             // here I don't use DELIMITER because it's not part of the
@@ -72,20 +80,19 @@ if (strlen($GLOBALS['db']) > 0
             // to avoid selecting alternatively the current and new db
             // we would need to modify the CREATE definitions to qualify
             // the db name
-            PMA_runProcedureAndFunctionDefinitions($GLOBALS['db']);
+            $operations->runProcedureAndFunctionDefinitions($GLOBALS['db']);
 
             // go back to current db, just in case
             $GLOBALS['dbi']->selectDb($GLOBALS['db']);
 
             $tables_full = $GLOBALS['dbi']->getTablesFull($GLOBALS['db']);
 
-            include_once "libraries/plugin_interface.lib.php";
             // remove all foreign key constraints, otherwise we can get errors
             /* @var $export_sql_plugin ExportSql */
-            $export_sql_plugin = PMA_getPlugin(
+            $export_sql_plugin = Plugins::getPlugin(
                 "export",
                 "sql",
-                'libraries/plugins/export/',
+                'libraries/classes/Plugins/Export/',
                 array(
                     'single_table' => isset($single_table),
                     'export_type'  => 'database'
@@ -93,60 +100,59 @@ if (strlen($GLOBALS['db']) > 0
             );
 
             // create stand-in tables for views
-            $views = PMA_getViewsAndCreateSqlViewStandIn(
+            $views = $operations->getViewsAndCreateSqlViewStandIn(
                 $tables_full, $export_sql_plugin, $GLOBALS['db']
             );
 
             // copy tables
-            $sqlConstratints = PMA_copyTables(
+            $sqlConstratints = $operations->copyTables(
                 $tables_full, $move, $GLOBALS['db']
             );
 
             // handle the views
             if (! $_error) {
-                PMA_handleTheViews($views, $move, $GLOBALS['db']);
+                $operations->handleTheViews($views, $move, $GLOBALS['db']);
             }
             unset($views);
 
             // now that all tables exist, create all the accumulated constraints
             if (! $_error && count($sqlConstratints) > 0) {
-                PMA_createAllAccumulatedConstraints($sqlConstratints);
+                $operations->createAllAccumulatedConstraints($sqlConstratints);
             }
             unset($sqlConstratints);
 
-            if (PMA_MYSQL_INT_VERSION >= 50100) {
+            if ($GLOBALS['dbi']->getVersion() >= 50100) {
                 // here DELIMITER is not used because it's not part of the
                 // language; each statement is sent one by one
 
-                PMA_runEventDefinitionsForDb($GLOBALS['db']);
+                $operations->runEventDefinitionsForDb($GLOBALS['db']);
             }
 
             // go back to current db, just in case
             $GLOBALS['dbi']->selectDb($GLOBALS['db']);
 
             // Duplicate the bookmarks for this db (done once for each db)
-            PMA_duplicateBookmarks($_error, $GLOBALS['db']);
+            $operations->duplicateBookmarks($_error, $GLOBALS['db']);
 
             if (! $_error && $move) {
                 if (isset($_REQUEST['adjust_privileges'])
                     && ! empty($_REQUEST['adjust_privileges'])
                 ) {
-                    PMA_AdjustPrivileges_moveDB($GLOBALS['db'], $_REQUEST['newname']);
+                    $operations->adjustPrivilegesMoveDb($GLOBALS['db'], $_REQUEST['newname']);
                 }
 
                 /**
                  * cleanup pmadb stuff for this db
                  */
-                include_once 'libraries/relation_cleanup.lib.php';
-                PMA_relationsCleanupDatabase($GLOBALS['db']);
+                RelationCleanup::database($GLOBALS['db']);
 
                 // if someday the RENAME DATABASE reappears, do not DROP
                 $local_query = 'DROP DATABASE '
-                    . PMA\libraries\Util::backquote($GLOBALS['db']) . ';';
+                    . Util::backquote($GLOBALS['db']) . ';';
                 $sql_query .= "\n" . $local_query;
                 $GLOBALS['dbi']->query($local_query);
 
-                $message = PMA\libraries\Message::success(
+                $message = Message::success(
                     __('Database %1$s has been renamed to %2$s.')
                 );
                 $message->addParam($GLOBALS['db']);
@@ -155,16 +161,16 @@ if (strlen($GLOBALS['db']) > 0
                 if (isset($_REQUEST['adjust_privileges'])
                     && ! empty($_REQUEST['adjust_privileges'])
                 ) {
-                    PMA_AdjustPrivileges_copyDB($GLOBALS['db'], $_REQUEST['newname']);
+                    $operations->adjustPrivilegesCopyDb($GLOBALS['db'], $_REQUEST['newname']);
                 }
 
-                $message = PMA\libraries\Message::success(
+                $message = Message::success(
                     __('Database %1$s has been copied to %2$s.')
                 );
                 $message->addParam($GLOBALS['db']);
                 $message->addParam($_REQUEST['newname']);
             } else {
-                $message = PMA\libraries\Message::error();
+                $message = Message::error();
             }
             $reload     = true;
 
@@ -175,10 +181,10 @@ if (strlen($GLOBALS['db']) > 0
                 if (isset($_REQUEST['switch_to_new'])
                     && $_REQUEST['switch_to_new'] == 'true'
                 ) {
-                    $GLOBALS['PMA_Config']->setCookie('pma_switch_to_new', 'true');
+                    $_SESSION['pma_switch_to_new'] = true;
                     $GLOBALS['db'] = $_REQUEST['newname'];
                 } else {
-                    $GLOBALS['PMA_Config']->setCookie('pma_switch_to_new', '');
+                    $_SESSION['pma_switch_to_new'] = false;
                 }
             }
         }
@@ -186,7 +192,7 @@ if (strlen($GLOBALS['db']) > 0
 
     /**
      * Database has been successfully renamed/moved.  If in an Ajax request,
-     * generate the output with {@link PMA\libraries\Response} and exit
+     * generate the output with {@link PhpMyAdmin\Response} and exit
      */
     if ($response->isAjax()) {
         $response->setRequestStatus($message->isSuccess());
@@ -194,7 +200,7 @@ if (strlen($GLOBALS['db']) > 0
         $response->addJSON('newname', $_REQUEST['newname']);
         $response->addJSON(
             'sql_query',
-            PMA\libraries\Util::getMessage(null, $sql_query)
+            Util::getMessage(null, $sql_query)
         );
         $response->addJSON('db', $GLOBALS['db']);
         exit;
@@ -204,15 +210,16 @@ if (strlen($GLOBALS['db']) > 0
 /**
  * Settings for relations stuff
  */
+$relation = new Relation();
 
-$cfgRelation = PMA_getRelationsParam();
+$cfgRelation = $relation->getRelationsParam();
 
 /**
  * Check if comments were updated
  * (must be done before displaying the menu tabs)
  */
 if (isset($_REQUEST['comment'])) {
-    PMA_setDbComment($GLOBALS['db'], $_REQUEST['comment']);
+    $relation->setDbComment($GLOBALS['db'], $_REQUEST['comment']);
 }
 
 require 'libraries/db_common.inc.php';
@@ -231,63 +238,61 @@ list(
     $tooltip_truename,
     $tooltip_aliasname,
     $pos
-) = PMA\libraries\Util::getDbInfo($db, isset($sub_part) ? $sub_part : '');
+) = Util::getDbInfo($db, isset($sub_part) ? $sub_part : '');
 
 echo "\n";
 
 if (isset($message)) {
-    echo PMA\libraries\Util::getMessage($message, $sql_query);
+    echo Util::getMessage($message, $sql_query);
     unset($message);
 }
 
 $_REQUEST['db_collation'] = $GLOBALS['dbi']->getDbCollation($GLOBALS['db']);
 $is_information_schema = $GLOBALS['dbi']->isSystemSchema($GLOBALS['db']);
 
-$response->addHTML('<div id="boxContainer" data-box-width="300">');
-
 if (!$is_information_schema) {
     if ($cfgRelation['commwork']) {
         /**
          * database comment
          */
-        $response->addHTML(PMA_getHtmlForDatabaseComment($GLOBALS['db']));
+        $response->addHTML($operations->getHtmlForDatabaseComment($GLOBALS['db']));
     }
 
-    $response->addHTML('<div class="operations_half_width">');
-    $response->addHTML(PMA_getHtmlForCreateTable($db));
+    $response->addHTML('<div>');
+    $response->addHTML(CreateTable::getHtml($db));
     $response->addHTML('</div>');
 
     /**
      * rename database
      */
     if ($GLOBALS['db'] != 'mysql') {
-        $response->addHTML(PMA_getHtmlForRenameDatabase($GLOBALS['db']));
+        $response->addHTML($operations->getHtmlForRenameDatabase($GLOBALS['db']));
     }
 
     // Drop link if allowed
     // Don't even try to drop information_schema.
     // You won't be able to. Believe me. You won't.
     // Don't allow to easily drop mysql database, RFE #1327514.
-    if (($is_superuser || $GLOBALS['cfg']['AllowUserDropDatabase'])
+    if (($GLOBALS['dbi']->isSuperuser() || $GLOBALS['cfg']['AllowUserDropDatabase'])
         && ! $db_is_system_schema
         && $GLOBALS['db'] != 'mysql'
     ) {
-        $response->addHTML(PMA_getHtmlForDropDatabaseLink($GLOBALS['db']));
+        $response->addHTML($operations->getHtmlForDropDatabaseLink($GLOBALS['db']));
     }
     /**
      * Copy database
      */
-    $response->addHTML(PMA_getHtmlForCopyDatabase($GLOBALS['db']));
+    $response->addHTML($operations->getHtmlForCopyDatabase($GLOBALS['db']));
 
     /**
      * Change database charset
      */
-    $response->addHTML(PMA_getHtmlForChangeDatabaseCharset($GLOBALS['db'], $table));
+    $response->addHTML($operations->getHtmlForChangeDatabaseCharset($GLOBALS['db'], $table));
 
     if (! $cfgRelation['allworks']
         && $cfg['PmaNoRelation_DisableWarning'] == false
     ) {
-        $message = PMA\libraries\Message::notice(
+        $message = Message::notice(
             __(
                 'The phpMyAdmin configuration storage has been deactivated. ' .
                 '%sFind out why%s.'
@@ -301,21 +306,3 @@ if (!$is_information_schema) {
         }
     } // end if
 } // end if (!$is_information_schema)
-
-$response->addHTML('</div>');
-
-// not sure about displaying the PDF dialog in case db is information_schema
-if ($cfgRelation['pdfwork'] && $num_tables > 0) {
-    // We only show this if we find something in the new pdf_pages table
-    $test_query = '
-        SELECT *
-        FROM ' . PMA\libraries\Util::backquote($GLOBALS['cfgRelation']['db'])
-        . '.' . PMA\libraries\Util::backquote($cfgRelation['pdf_pages']) . '
-        WHERE db_name = \'' . $GLOBALS['dbi']->escapeString($GLOBALS['db'])
-        . '\'';
-    $test_rs = PMA_queryAsControlUser(
-        $test_query,
-        false,
-        PMA\libraries\DatabaseInterface::QUERY_STORE
-    );
-} // end if
