@@ -6,6 +6,9 @@
  * @package PhpMyAdmin
  */
 
+use PhpMyAdmin\Core;
+use PhpMyAdmin\Display\ImportAjax;
+
 /* PHP 5.4 stores upload progress data only in the default session.
  * After calling session_name(), we won't find the progress data anymore.
  *
@@ -49,12 +52,11 @@ if (ini_get('session.upload_progress.enabled')) {
 define('PMA_MINIMUM_COMMON', 1);
 
 require_once 'libraries/common.inc.php';
-require_once 'libraries/display_import_ajax.lib.php';
 list(
     $SESSION_KEY,
     $upload_id,
     $plugins
-) = PMA_uploadProgressSetup();
+) = ImportAjax::uploadProgressSetup();
 
 /*
 if (defined('SESSIONUPLOAD')) {
@@ -81,7 +83,7 @@ if (defined('SESSIONUPLOAD')) {
 if (isset($_GET["message"]) && $_GET["message"]) {
 
     // AJAX requests can't be cached!
-    PMA_noCacheHeader();
+    Core::noCacheHeader();
 
     header('Content-type: text/html');
 
@@ -101,7 +103,7 @@ if (isset($_GET["message"]) && $_GET["message"]) {
         session_start();
 
         if ((time() - $timestamp) > $maximumTime) {
-            $_SESSION['Import_message']['message'] = PMA\libraries\Message::error(
+            $_SESSION['Import_message']['message'] = PhpMyAdmin\Message::error(
                 __('Could not load the progress of the import.')
             )->getDisplay();
             break;
@@ -115,5 +117,5 @@ if (isset($_GET["message"]) && $_GET["message"]) {
     echo '</fieldset>' , "\n";
 
 } else {
-    PMA_importAjaxStatus($_GET["id"]);
+    ImportAjax::status($_GET["id"]);
 }
