@@ -169,9 +169,17 @@ AJAX.registerOnload('sql.js', function () {
                 PMA_autosaveSQL($('#sqlquery').val());
             });
             // Save sql query with sort
-            $('select[name="sql_query"]').on('change', function () {
-                PMA_autosaveSQLSort($('select[name="sql_query"]').val());
-            });
+            if ($('#RememberSorting') !== undefined && $('#RememberSorting').is(':checked')) {
+                $('select[name="sql_query"]').on('change', function () {
+                    PMA_autosaveSQLSort($('select[name="sql_query"]').val());
+                });
+            } else {
+                if (isStorageSupported('localStorage') && window.localStorage.auto_saved_sql_sort !== undefined) {
+                    window.localStorage.removeItem('auto_saved_sql_sort');
+                } else {
+                    Cookies.set('auto_saved_sql_sort', '');
+                }
+            }
             // If sql query with sort for current table is stored, change sort by key select value
             var sortStoredQuery = (isStorageSupported('localStorage') && typeof window.localStorage.auto_saved_sql_sort !== 'undefined') ? window.localStorage.auto_saved_sql_sort : Cookies.get('auto_saved_sql_sort');
             if (typeof sortStoredQuery !== 'undefined' && sortStoredQuery !== $('select[name="sql_query"]').val() && $('select[name="sql_query"] option[value="' + sortStoredQuery + '"]').length !== 0) {
