@@ -123,7 +123,7 @@ class Events
                             htmlspecialchars($drop_item)
                         )
                         . '<br />'
-                        . __('MySQL said: ') . $GLOBALS['dbi']->getError(null);
+                        . __('MySQL said: ') . $GLOBALS['dbi']->getError();
                     } else {
                         $result = $GLOBALS['dbi']->tryQuery($item_query);
                         if (! $result) {
@@ -132,7 +132,7 @@ class Events
                                 htmlspecialchars($item_query)
                             )
                             . '<br />'
-                            . __('MySQL said: ') . $GLOBALS['dbi']->getError(null);
+                            . __('MySQL said: ') . $GLOBALS['dbi']->getError();
                             // We dropped the old item, but were unable to create
                             // the new one. Try to restore the backup query
                             $result = $GLOBALS['dbi']->tryQuery($create_item);
@@ -163,7 +163,7 @@ class Events
                             htmlspecialchars($item_query)
                         )
                         . '<br /><br />'
-                        . __('MySQL said: ') . $GLOBALS['dbi']->getError(null);
+                        . __('MySQL said: ') . $GLOBALS['dbi']->getError();
                     } else {
                         $message = Message::success(
                             __('Event %1$s has been created.')
