@@ -1,29 +1,27 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
-
 /**
  * Handles server charsets and collations page.
  *
  * @package PhpMyAdmin
  */
 
-namespace PMA;
-
-use PMA\libraries\controllers\server\ServerCollationsController;
-use PMA\libraries\Response;
+use PhpMyAdmin\Controllers\Server\ServerCollationsController;
+use PhpMyAdmin\Di\Container;
+use PhpMyAdmin\Response;
 
 require_once 'libraries/common.inc.php';
 
-$container = libraries\di\Container::getDefaultContainer();
+$container = Container::getDefaultContainer();
 $container->factory(
-    'PMA\libraries\controllers\server\ServerCollationsController'
+    'PhpMyAdmin\Controllers\Server\ServerCollationsController'
 );
 $container->alias(
     'ServerCollationsController',
-    'PMA\libraries\controllers\server\ServerCollationsController'
+    'PhpMyAdmin\Controllers\Server\ServerCollationsController'
 );
-$container->set('PMA\libraries\Response', Response::getInstance());
-$container->alias('response', 'PMA\libraries\Response');
+$container->set('PhpMyAdmin\Response', Response::getInstance());
+$container->alias('response', 'PhpMyAdmin\Response');
 
 /** @var ServerCollationsController $controller */
 $controller = $container->get(
