@@ -6,23 +6,18 @@
  * @package PhpMyAdmin-Setup
  */
 
-use PMA\libraries\config\ConfigFile;
-use PMA\libraries\config\FormDisplay;
-use PMA\libraries\URL;
+use PhpMyAdmin\Config\ConfigFile;
+use PhpMyAdmin\Config\Forms\Setup\ServersForm;
+use PhpMyAdmin\Core;
+use PhpMyAdmin\Setup\FormProcessing;
+use PhpMyAdmin\Url;
 
 if (!defined('PHPMYADMIN')) {
     exit;
 }
 
-/**
- * Core libraries.
- */
-require_once './setup/lib/form_processing.lib.php';
-
-require './libraries/config/setup.forms.php';
-
 $mode = isset($_GET['mode']) ? $_GET['mode'] : null;
-$id = PMA_isValid($_GET['id'], 'numeric') ? intval($_GET['id']) : null;
+$id = Core::isValid($_GET['id'], 'numeric') ? intval($_GET['id']) : null;
 
 /** @var ConfigFile $cf */
 $cf = $GLOBALS['ConfigFile'];
@@ -34,7 +29,7 @@ if ($mode == 'edit' && $server_exists) {
         . ' <small>(' . htmlspecialchars($cf->getServerDSN($id)) . ')</small>';
 } elseif ($mode == 'remove' && $server_exists) {
     $cf->removeServer($id);
-    header('Location: index.php' . URL::getCommonRaw());
+    header('Location: index.php' . Url::getCommonRaw());
     exit;
 } elseif ($mode == 'revert' && $server_exists) {
     // handled by process_formset()
@@ -45,8 +40,5 @@ if ($mode == 'edit' && $server_exists) {
 if (isset($page_title)) {
     echo '<h2>' , $page_title . '</h2>';
 }
-$form_display = new FormDisplay($cf);
-foreach ($forms['Servers'] as $form_name => $form) {
-    $form_display->registerForm($form_name, $form, $id);
-}
-PMA_Process_formset($form_display);
+$form_display = new ServersForm($cf, $id);
+FormProcessing::process($form_display);
