@@ -3333,10 +3333,6 @@ body .ui-dialog .ui-button-text-only .ui-button-text {
     display: none;
 }
 
-.responsivetable {
-    overflow-x: auto;
-}
-
 @media only screen and (max-width: 768px) {
     /* For mobile phones: */
     #main_pane_left {
