@@ -40,10 +40,6 @@ $view_security_options = array(
     'INVOKER'
 );
 
-if (empty($sql_query)) {
-    $sql_query = '';
-}
-
 // View name is a compulsory field
 if (isset($_REQUEST['view']['name'])
     && empty($_REQUEST['view']['name'])
@@ -175,6 +171,8 @@ if (isset($_REQUEST['createview']) || isset($_REQUEST['alterview'])) {
     exit;
 }
 
+$sql_query = ! empty($_GET['sql_query']) ? $_GET['sql_query'] : '';
+
 // prefill values if not already filled from former submission
 $view = array(
     'operation' => 'create',
@@ -196,8 +194,11 @@ $url_params['db'] = $GLOBALS['db'];
 $url_params['reload'] = 1;
 
 echo Template::get('view_create')->render([
-    'ajax_dialog'           => isset($_REQUEST['ajax_dialog']),
-    'text_dir'              => $text_dir,
-    'url_params'            => $url_params,
-    'view'                  => $view,
+    'ajax_dialog' => isset($_REQUEST['ajax_dialog']),
+    'text_dir' => $text_dir,
+    'url_params' => $url_params,
+    'view' => $view,
+    'view_algorithm_options' => $view_algorithm_options,
+    'view_with_options' => $view_with_options,
+    'view_security_options' => $view_security_options,
 ]);
